"""
Base class for jury members (individual language models).
"""
from abc import ABC, abstractmethod
from typing import Any, Dict, Optional

class JuryMember(ABC):
    def __init__(self, name: str, model_id: str, **kwargs: Any):
        """
        Initialize a jury member.
        
        Args:
            name: Name of the jury member
            model_id: Identifier for the model (e.g., HuggingFace model ID)
            **kwargs: Additional configuration parameters
        """
        self.name = name
        self.model_id = model_id
        self.config = kwargs
        
    @abstractmethod
    def process(self, prompt: str, **kwargs: Any) -> Dict[str, Any]:
        """
        Process the input prompt and return response.
        
        Args:
            prompt: Input text to process
            **kwargs: Additional processing parameters
            
        Returns:
            Dictionary containing the response and any metadata
        """
        pass
    
    @abstractmethod
    def load_model(self) -> None:
        """Load the underlying model."""
        pass
    
    def __repr__(self) -> str:
        return f"{self.__class__.__name__}(name={self.name}, model_id={self.model_id})"



"""
JuryLLM: A framework for collaborative language model decision-making
"""

__version__ = "0.1.0"
__author__ = "Sujith"

from .jury import Jury
from .model import JuryMember

__all__ = ["Jury", "JuryMember"]



"""
Core Jury class that manages the ensemble of language models.
"""
from typing import List, Optional, Dict, Any

from .model import JuryMember

class Jury:
    def __init__(self, members: Optional[List[JuryMember]] = None):
        """
        Initialize a Jury with optional list of JuryMembers.
        
        Args:
            members: Optional list of JuryMember instances
        """
        self.members = members or []
        
    def add_member(self, member: JuryMember) -> None:
        """Add a new member to the jury."""
        self.members.append(member)
        
    def deliberate(self, prompt: str, **kwargs: Any) -> Dict[str, Any]:
        """
        Have all jury members deliberate on a prompt and return collective output.
        
        Args:
            prompt: The input prompt for deliberation
            **kwargs: Additional arguments for the deliberation process
            
        Returns:
            Dictionary containing the collective decision and individual responses
        """
        responses = []
        for member in self.members:
            response = member.process(prompt, **kwargs)
            responses.append(response)
            
        # TODO: Implement consensus mechanism
        consensus = self._reach_consensus(responses)
        
        return {
            "consensus": consensus,
            "individual_responses": responses
        }
    
    def _reach_consensus(self, responses: List[Any]) -> Any:
        """
        Internal method to reach consensus from individual responses.
        To be implemented based on specific consensus mechanisms.
        """
        # TODO: Implement sophisticated consensus mechanism
        return responses[0] if responses else None



from setuptools import setup, find_packages
import os

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Base requirements
requirements = [
    "ollama>=0.4.4",
    "pydantic>=2.0.0",
    "openai>=1.57.2",
]

# If requirements.txt exists, use it instead
if os.path.exists("requirements.txt"):
    with open("requirements.txt", "r", encoding="utf-8") as fh:
        requirements = [line.strip() for line in fh if line.strip() and not line.startswith("#")]

setup(
    name="juryllm",
    version="0.1.0",
    author="Sujith",
    description="An experimental framework for collaborative language model decision-making",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sujith/juryLLM",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    python_requires=">=3.8",
    install_requires=requirements,
)
